@@ -69,7 +69,10 @@ except AttributeError:
     TIMEOUT_MAX = 1e10
 
 
-_Semaphore = threading._Semaphore
+try:
+    _Semaphore = threading._Semaphore
+except AttributeError:  # Py3
+    _Semaphore = threading.Semaphore  # noqa
 
 #
 # Constants representing the state of a pool
@@ -134,7 +137,7 @@ def stop_if_not_current(thread, timeout=None):
         thread.stop(timeout)
 
 
-class LaxBoundedSemaphore(threading._Semaphore):
+class LaxBoundedSemaphore(_Semaphore):
     """Semaphore that checks that # release is <= # acquires,
     but ignores if # releases >= value."""
 
@@ -334,7 +337,7 @@ class PoolThread(threading.Thread):
         except RestartFreqExceeded, exc:
             error("Thread %r crashed: %r", type(self).__name__, exc,
                   exc_info=True)
-            os.kill(os.getpid(), signal.SIGTERM)
+            _kill(os.getpid(), signal.SIGTERM)
             sys.exit()
         except Exception, exc:
             error("Thread %r crashed: %r", type(self).__name__, exc,
@@ -487,7 +490,7 @@ class TimeoutHandler(PoolThread):
             job._timeout_callback(soft=True, timeout=job._soft_timeout)
 
         try:
-            os.kill(job._worker_pid, SIG_SOFT_TIMEOUT)
+            _kill(job._worker_pid, SIG_SOFT_TIMEOUT)
         except OSError, exc:
             if exc.errno != errno.ESRCH:
                 raise
